package ical

import (
	"encoding/json"
	"github.com/pocketbase/dbx"
	"github.com/pocketbase/pocketbase"
	"htwkalender/model"
)

//update ical feed json
//add uuid field
//remove module name field

func MigrateFeedJson(app *pocketbase.PocketBase) error {

	records, err := app.Dao().FindRecordsByFilter("feeds", "1=1", "-created", 0, 0)
	if err != nil {
		return err
	}

	for _, feed := range records {

		var modules []model.FeedCollection

		err := json.Unmarshal([]byte(feed.GetString("modules")), &modules)
		if err != nil {
			return err
		}

		var uuidFeedCollections []model.FeedCollection

		for _, module := range modules {
			uuid := searchUUIDForModule(app, module.Name)

			if uuid != "" {
				uuidFeedCollections = append(uuidFeedCollections, model.FeedCollection{UUID: uuid, Name: module.Name, Course: module.Course, UserDefinedName: module.UserDefinedName})
			}
		}

		jsonModules, _ := json.Marshal(uuidFeedCollections)
		feed.Set("modules", string(jsonModules))

		err = app.Dao().SaveRecord(feed)
		if err != nil {
			return err
		}
	}
	return nil
}

func searchUUIDForModule(app *pocketbase.PocketBase, moduleName string) string {
	var event model.Event
	err := app.Dao().DB().Select("*").From("events").Where(dbx.NewExp("Name = {:name}", dbx.Params{"name": moduleName})).One(&event)
	if err != nil {
		return ""
	}
	return event.UUID
}
